{ inputs, pkgs, config, lib, ... }: {
  imports = [
    ../../templates/proxmox-lxc.nix
    ../../server.nix
    ../../features/podman.nix
  ];

  networking.hostName = "pihole";
  system.stateVersion = "24.05";
  nixpkgs.hostPlatform = "x86_64-linux";

  networking.firewall = {
    allowedTCPPorts = [ 53 80 ];
    allowedUDPPorts = [ 53 ];
  };

  services.resolved = {
    enable = false;
  };

  networking.nameservers = [
    "2606:4700:4700::1111#one.one.one.one"
    "2606:4700:4700::1001#one.one.one.one"
    "1.1.1.1#one.one.one.one" 
    "1.0.0.1#one.one.one.one" 
  ];
  
  virtualisation.oci-containers.containers = {
    pihole = {
      image = "registry-1.docker.io/pihole/pihole";
      ports = [
        "53:53/tcp"
        "53:53/udp"
        "80:80/tcp"
      ];
      volumes = [
        "etc-pihole:/etc/pihole"
        "etc-dnsmasq.d:/etc/dnsmasq.d"
      ];
      environment = {
        TZ = config.time.timeZone;
        VIRTUAL_HOST = "pihole.hoki-porgy.ts.net";
        PROXY_LOCATION = "pihole.hoki-porgy.ts.net";
        # FTLCONF_LOCAL_IPV4 = config.networking.interfaces.tailscale0.ipv4.addresses[0].address;
      };
    };
  };
}
